%define upstream_name    Switch
%define upstream_version 2.17

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 9

Summary:    A switch statement for Perl
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module//%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Filter::Util::Call)
BuildRequires: perl(Text::Balanced) >= 2.0.0
BuildRequires: perl(if)
BuildArch:  noarch

%description
The Switch.pm module implements a generalized case mechanism that covers
most (but not all) of the numerous possible combinations of switch and case
values described above.

The module augments the standard Perl syntax with two new control
statements: 'switch' and 'case'. The 'switch' statement takes a single
scalar argument of any type, specified in parentheses. 'switch' stores this
value as the current switch value in a (localized) control variable. The
value is followed by a block which may contain one or more Perl statements
(including the 'case' statement described below). The block is
unconditionally executed once the switch value has been cached.

A 'case' statement takes a single scalar argument (in mandatory parentheses
if it's a variable; otherwise the parens are optional) and selects the
appropriate type of matching between that argument and the current switch
value. The type of matching used is determined by the respective types of
the switch value and the 'case' argument, as specified in Table 1. If the
match is successful, the mandatory block associated with the 'case'
statement is executed.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%make_install

%files
%doc Changes META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%perl_vendorlib/*

%changelog
* Thu Jun 26 2025 umeabot <umeabot> 2.170.0-9.mga10
+ Revision: 2200737
- Mageia 10 Mass Rebuild

* Sun Mar 20 2022 umeabot <umeabot> 2.170.0-8.mga9
+ Revision: 1805884
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 2.170.0-7.mga8
+ Revision: 1497242
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Wed Sep 19 2018 umeabot <umeabot> 2.170.0-6.mga7
+ Revision: 1271332
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 2.170.0-5.mga6
+ Revision: 1033581
- Rebuild for perl 5.22.2

* Sun Jan 31 2016 umeabot <umeabot> 2.170.0-4.mga6
+ Revision: 929483
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.170.0-3.mga5
+ Revision: 745919
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.170.0-2.mga5
+ Revision: 686276
- Mageia 5 Mass Rebuild

* Fri Apr 18 2014 jquelin <jquelin> 2.170.0-1.mga5
+ Revision: 616325
- update to 2.17

* Fri Oct 18 2013 umeabot <umeabot> 2.160.0-5.mga4
+ Revision: 514778
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 2.160.0-4.mga3
+ Revision: 372896
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 05 2012 jquelin <jquelin> 2.160.0-3.mga3
+ Revision: 326931
- fix prototype abuse (rt#60380)

* Fri Jan 21 2011 jquelin <jquelin> 2.160.0-2.mga1
+ Revision: 29186
- mageia rebuild
- imported package perl-Switch

